# NETWORK DIFFUSION

[![Build Status](https://travis-ci.com/anty-filidor/network_diffusion.svg?branch=master)](https://travis-ci.com/anty-filidor/network_diffusion)
[![Documentation Status](https://readthedocs.org/projects/network-diffusion/badge/?version=latest)](https://network-diffusion.readthedocs.io/en/latest)
[![codecov](https://codecov.io/gh/anty-filidor/network_diffusion/branch/master/graph/badge.svg?token=LF52GAD73F)](https://codecov.io/gh/anty-filidor/network_diffusion)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2Fanty-filidor%2Fnetwork_diffusion.svg?type=shield)](https://app.fossa.com/projects/git%2Bgithub.com%2Fanty-filidor%2Fnetwork_diffusion?ref=badge_shield)

[![License: GPL](https://img.shields.io/github/license/anty-filidor/network_diffusion)](https://www.gnu.org/licenses/gpl-3.0.html)
[![PyPI version](https://badge.fury.io/py/network-diffusion.svg)](https://badge.fury.io/py/network-diffusion)
[![Conda version](https://anaconda.org/anty-filidor/network_diffusion/badges/version.svg)](https://anaconda.org/anty-filidor/network_diffusion)

This repository contains a a package to design and run diffusion phenomena processes in
networks. Package has been built basing on [networkx](https://networkx.github.io)
library and is fully compatible with it.

Documentation and tutorials are available
[here](https://network-diffusion.readthedocs.io/en/latest/).

## Installation of the package:

pip: `pip install network_diffusion`

conda: `conda install -c anty-filidor network_diffusion`

## Contact with author

In case of questions for the maintainer please send mails here:
<michal.czuba.1995@gmail.com>.
